@@ -14,7 +14,10 @@ from pyupgrade._data import TokenFunc
 from pyupgrade._token_helpers import find_closing_bracket
 from pyupgrade._token_helpers import find_open_paren
 
-NUM_TYPES = {
+_TYPES = {
+    bool: 'bool',
+    bytes: 'bytes',
+    str: 'str',
     int: 'int',
     float: 'float',
     complex: 'complex',
@@ -42,23 +45,12 @@ def visit_Call(
     if (
             isinstance(node.func, ast.Name) and
             node.func.id == 'type' and
-            len(node.args) == 1
+            len(node.args) == 1 and
+            isinstance(node.args[0], ast.Constant) and
+            node.args[0].value not in {Ellipsis, None}
     ):
-        if isinstance(node.args[0], ast.Str):
-            func = functools.partial(
-                _rewrite_type_of_primitive,
-                src='str',
-            )
-            yield ast_to_offset(node), func
-        elif isinstance(node.args[0], ast.Bytes):
-            func = functools.partial(
-                _rewrite_type_of_primitive,
-                src='bytes',
-            )
-            yield ast_to_offset(node), func
-        elif isinstance(node.args[0], ast.Num):
-            func = functools.partial(
-                _rewrite_type_of_primitive,
-                src=NUM_TYPES[type(node.args[0].n)],
-            )
-            yield ast_to_offset(node), func
+        func = functools.partial(
+            _rewrite_type_of_primitive,
+            src=_TYPES[type(node.args[0].value)],
+        )
+        yield ast_to_offset(node), func
